import React, { useEffect, useMemo, useState, useCallback } from 'react'
import { Icon, Upload, Modal } from 'antd'
import { fetch, apis } from '@/utils/request'

const postMiniApp = fetch(apis.mp.miniapp)

export default props => {
  const [previewVisible, setPreviewVisible] = useState(false)
  const [previewImage, setPreviewImage] = useState()
  const [imageUrl, setImageUrl] = useState()
  const [fileList, setFileList] = useState([])

  const uploadButton = useMemo(() => {
    return (
      <div>
        <Icon type="plus" />
        <div>Upload</div>
      </div>
    )
  }, [])
  
  const customRequest = useCallback(({file, onError, onSuccess}) => {
    const data = new FormData()
    data.append('file', file)

    postMiniApp({ data }).then((res) => {
      setImageUrl(res.url)
      setFileList([{
        uid: '-1',
        name: 'image.png',
        status: 'done',
        url: res.url,
      }])
      props.onChange(res)
      onSuccess(res.url, file)
    }).catch(onError)

    return {
      abort() {
        console.log('upload progress is aborted.');
      },
    }
  }, [])

  useEffect(() => {
    if (props.value) {
      setFileList([{
        uid: '-1',
        name: 'image.png',
        status: 'done',
        url: props.value,
      }])
    }
  }, [props.value])

  return (
    <div>
      <Upload
        name="file"
        accept=".png, .jpg, .jpeg, .gif"
        listType="picture-card"
        fileList={fileList}
        customRequest={customRequest}
        onPreview={() => setPreviewVisible(true)}
      >
        {fileList.length >= 1 ? null : uploadButton}
      </Upload>
      <Modal visible={previewVisible} footer={null} onCancel={() => setPreviewVisible(false)}>
        <img alt="" style={{ width: '100%' }} src={previewImage} />
      </Modal>
    </div>
  )
}
